@@ -1,15 +1,10 @@
-from __future__ import print_function
-import sys
-import Pyro4
-
-if sys.version_info < (3, 0):
-    input = raw_input
+import Pyro5.api
 
 
 uri = input("enter attribute server object uri: ").strip()
 
 
-with Pyro4.Proxy(uri) as p:
+with Pyro5.api.Proxy(uri) as p:
     # Direct remote attribute access.
     print("\nDirect attribute access:")
     print("p.prop_value=", p.prop_value)
@@ -26,7 +21,7 @@ with Pyro4.Proxy(uri) as p:
     print("calling p.__dunder__()....: ", p.__dunder__())
 
 
-with Pyro4.Proxy(uri) as p:
+with Pyro5.api.Proxy(uri) as p:
     # unexposed attributes
     print("\nAccessing unexposed attributes:")
     try:
@@ -55,7 +50,7 @@ with Pyro4.Proxy(uri) as p:
         print("ok, got expected error:", x)
 
 
-with Pyro4.Proxy(uri) as p:
+with Pyro5.api.Proxy(uri) as p:
     # Dotted name traversal is not supported by Pyro because that is a security vulnerability.
     # What will happen instead is that the first part of the name will be evaluated and returned,
     # and that the rest of the expression will be evaluated on the local object instead of
