@@ -1,14 +1,8 @@
-from __future__ import print_function
-import sys
+import Pyro5.api
 
-import Pyro4
-
-
-if sys.version_info < (3, 0):
-    input = raw_input
 
 uri = input("enter factory server object uri: ").strip()
-factory = Pyro4.Proxy(uri)
+factory = Pyro5.api.Proxy(uri)
 
 # create several things.
 print("Creating things.")
@@ -16,8 +10,10 @@ thing1 = factory.createSomething(1)
 thing2 = factory.createSomething(2)
 thing3 = factory.createSomething(3)
 
+print(repr(thing1))
+
 # interact with them on the server.
-print("Speaking stuff.")
+print("Speaking stuff (see output on server).")
 thing1.speak("I am the first")
 thing2.speak("I am second")
 thing3.speak("I am last then...")
