@@ -1,8 +1,8 @@
 import time
-import Pyro4
+from Pyro5.api import expose, serve
 
 
-@Pyro4.expose
+@expose
 class Thingy(object):
     def multiply(self, a, b):
         return a * b
@@ -25,6 +25,6 @@ class Thingy(object):
         return 0
 
 
-Pyro4.Daemon.serveSimple({
+serve({
     Thingy: "example.batched"
-}, ns=False)
+}, use_ns=False)
