@@ -1,6 +1,7 @@
-import Pyro4
+from Pyro5.api import expose, oneway
 
 
+@expose
 class bench(object):
     def length(self, string):
         return len(string)
@@ -29,7 +30,7 @@ class bench(object):
     def echo(self, *args):
         return args
 
-    @Pyro4.oneway
+    @oneway
     def oneway(self, *args):
         # oneway doesn't return anything
         pass
