@@ -1,9 +1,8 @@
-import Pyro4
-import Pyro4.util
+from Pyro5.api import expose, Proxy, register_dict_to_class
 from customdata import CustomData
 
-# teach Serpent how to deserialize our custom data class
-Pyro4.util.SerializerBase.register_dict_to_class(CustomData.serialized_classname, CustomData.from_dict)
+# teach the serializer how to deserialize our custom data class
+register_dict_to_class(CustomData.serialized_classname, CustomData.from_dict)
 
 
 class Listener(object):
@@ -11,10 +10,10 @@ class Listener(object):
         self.topic = topic
 
     def register_with_dispatcher(self):
-        with Pyro4.Proxy("PYRONAME:example.blobdispatcher") as dispatcher:
+        with Proxy("PYRONAME:example.blobdispatcher") as dispatcher:
             dispatcher.register(self.topic, self)
 
-    @Pyro4.expose
+    @expose
     def process_blob(self, blob):
         assert blob.info == self.topic
         customdata = blob.deserialized()
