@@ -1,5 +1,5 @@
 import time
-import Pyro4
+from Pyro5.api import expose, oneway, serve
 
 
 class Worker(object):
@@ -8,13 +8,14 @@ class Worker(object):
         self.callback = callback
         print("Worker %d created" % self.number)
 
-    @Pyro4.expose
-    @Pyro4.oneway
+    @expose
+    @oneway
     def work(self, amount):
         print("Worker %d busy..." % self.number)
         time.sleep(amount)
         print("Worker %d done. Informing callback client." % self.number)
         self._pyroDaemon.unregister(self)
+        self.callback._pyroClaimOwnership()     # because this method may run in a different thread every time it's called
         self.callback.done(self.number)  # invoke the callback object
 
 
@@ -22,7 +23,7 @@ class CallbackServer(object):
     def __init__(self):
         self.number = 0
 
-    @Pyro4.expose
+    @expose
     def addworker(self, callback):
         self.number += 1
         print("server: adding worker %d" % self.number)
@@ -31,6 +32,6 @@ class CallbackServer(object):
         return worker
 
 
-Pyro4.Daemon.serveSimple({
+serve({
     CallbackServer: "example.callback"
 })
