@@ -1,13 +1,12 @@
-from __future__ import print_function, division
 import zipfile
 import time
 from collections import Counter
-import Pyro4
+from Pyro5.api import Proxy
 
 
 def wordfreq(book, counter_uri):
     begin = time.time()
-    with Pyro4.Proxy(counter_uri) as counter:
+    with Proxy(counter_uri) as counter:
         totals = counter.count(book)
         totals = Counter(totals)
     time_taken = round(time.time()-begin, 2)
@@ -24,7 +23,7 @@ if __name__ == "__main__":
     print("(artificial delays are used to dramatize the differences in execution time)")
 
     print("\nCounting the words using a single counter...")
-    wordfreq(book, "PYRONAME:example.dc.wordcount.1")
+    wordfreq(book, "PYRONAME:example.dc2.wordcount.1")
 
     print("\nCounting words using multiple parallel counters...")
-    wordfreq(book, "PYRONAME:example.dc.dispatcher")
+    wordfreq(book, "PYRONAME:example.dc2.dispatcher")
