@@ -1,10 +1,10 @@
 # ascii animation of zooming a mandelbrot fractal,  z=z^2+c
-from __future__ import print_function, division
 import os
 import time
 import platform
 from server import Mandelbrot
 
+
 res_x = 100
 res_y = 40
 
@@ -23,7 +23,7 @@ def cls():
         os.system("cls")
     else:
         print(chr(27)+"[2J"+chr(27)+"[1;1H", end="")  # ansi clear screen
-    
+
 
 def zoom():
     start = -2.0-1.0j
@@ -31,6 +31,7 @@ def zoom():
     duration = 30.0
     wallclock_start = time.time()
     frames = 0
+    fps = 0
     cls()
     print("This is a mandelbrot zoom animation running without Pyro, in a single Python process.")
     time.sleep(2)
