@@ -1,13 +1,7 @@
-import pickle
-import Pyro4
+from Pyro5.api import expose, oneway
 
 
-class UnserializableError(Exception):
-    def __reduce__(self):
-        raise pickle.PicklingError("make this nonpickleable")
-
-
-@Pyro4.expose
+@expose
 class TestClass(object):
     def div(self, arg1, arg2):
         return arg1 / arg2
@@ -21,12 +15,16 @@ class TestClass(object):
     def othererr(self):
         raise RuntimeError('a runtime error!')
 
+    @oneway
+    def onewayerr(self):
+        raise ValueError('error in oneway call!')
+
     def complexerror(self):
         x = Foo()
         x.crash()
 
     def unserializable(self):
-        raise UnserializableError("this error can't be serialized")
+        return TestClass.unserializable
 
 
 class Foo(object):
