@@ -1,22 +1,13 @@
-from __future__ import print_function
-import sys
 import time
 import warnings
-
-import Pyro4
 import serpent
+from Pyro5.api import Proxy, config
 
 
 warnings.filterwarnings("ignore")
 
-# Pyro4.config.COMMTIMEOUT=2
-
 print("Enter the server's uri that was printed:")
-if sys.version_info < (3, 0):
-    uri = raw_input()
-else:
-    uri = input()
-uri = uri.strip()
+uri = input().strip()
 
 datasize = 5 * 1024 * 1024  # 5 mb
 
@@ -25,7 +16,7 @@ def do_test(data):
     assert len(data) == datasize
     totalsize = 0
 
-    with Pyro4.core.Proxy(uri) as obj:
+    with Proxy(uri) as obj:
         obj._pyroBind()
 
         begin = time.time()
@@ -38,11 +29,12 @@ def do_test(data):
 
         totalsize = float(totalsize)
         print("It took %.2f seconds to transfer %d mb." % (duration, totalsize / 1024 / 1024))
-        print("That is %.0f kb/sec. = %.1f mb/sec. (serializer: %s)" % (totalsize / 1024 / duration, totalsize / 1024 / 1024 / duration, Pyro4.config.SERIALIZER))
+        print("That is %.0f kb/sec. = %.1f mb/sec. (serializer: %s)" %
+              (totalsize / 1024 / duration, totalsize / 1024 / 1024 / duration, config.SERIALIZER))
 
 
 def do_test_chunks():
-    with Pyro4.core.Proxy(uri) as p:
+    with Proxy(uri) as p:
         totalsize = 0
         begin = time.time()
         for chunk in p.download_chunks(datasize*10):
@@ -52,8 +44,9 @@ def do_test_chunks():
         assert totalsize == datasize*10
         duration = time.time() - begin
         totalsize = float(totalsize)
-        print("It took %.2f seconds to transfer %d mb." % (duration, totalsize / 1024 / 1024))
-        print("That is %.0f kb/sec. = %.1f mb/sec. (serializer: %s)" % (totalsize / 1024 / duration, totalsize / 1024 / 1024 / duration, Pyro4.config.SERIALIZER))
+        print("\nIt took %.2f seconds to transfer %d mb." % (duration, totalsize / 1024 / 1024))
+        print("That is %.0f kb/sec. = %.1f mb/sec. (serializer: %s)" %
+              (totalsize / 1024 / duration, totalsize / 1024 / 1024 / duration, config.SERIALIZER))
 
 
 data = 'x' * datasize
@@ -67,4 +60,4 @@ print("\n\n----test with bytearray data----")
 do_test(data)
 print("\n\n----test download via iterator----")
 do_test_chunks()
-print("\n\n   (tip: also see the 'filetransfer' example for more efficient ways to transfer large amoungs of binary data)")
\ No newline at end of file
+print("\n\n (tip: also see the 'filetransfer' example for more efficient ways to transfer large amounts of binary data)")
