@@ -1,32 +1,25 @@
-from __future__ import print_function
-import sys
-
-import Pyro4
-import Pyro4.errors
+import Pyro5.errors
+import Pyro5.api
 
 
 huge_object = [42] * 10000
 simple_object = {"message": "hello", "irrelevant": huge_object}
 
 print("First start the built-in test echo server with something like:")
-print("$ python -m Pyro4.test.echoserver")
+print("$ python -m Pyro5.utils.echoserver")
 print("Enter the server's uri that was printed:")
-if sys.version_info < (3, 0):
-    uri = raw_input()
-else:
-    uri = input()
-uri = uri.strip()
-echoserver = Pyro4.Proxy(uri)
+uri = input().strip()
+echoserver = Pyro5.api.Proxy(uri)
 
-Pyro4.config.MAX_MESSAGE_SIZE = 0
-print("\nSending big data with no limit on message size...")
+Pyro5.config.MAX_MESSAGE_SIZE = 2**32
+print("\nSending big data with virtually no limit on message size...")
 response = echoserver.echo(simple_object)
 print("success.")
 
 try:
-    Pyro4.config.MAX_MESSAGE_SIZE = 2500
+    Pyro5.config.MAX_MESSAGE_SIZE = 2500
     print("\nSending big data with a limit on message size...")
     response = echoserver.echo(simple_object)
     print("Hmm, this should have raised an exception")
-except Pyro4.errors.MessageTooLargeError as x:
+except Pyro5.errors.MessageTooLargeError as x:
     print("EXCEPTION (expected):", x)
