@@ -1,18 +1,17 @@
 """
 This is the producer for the 'many topics' messages example.
 """
-from __future__ import print_function
 import time
 import random
 import sys
-import Pyro4
-from Pyro4.util import excepthook
+import Pyro5.errors
+from Pyro5.api import Proxy
 from messagebus import PYRO_MSGBUS_NAME
 
-sys.excepthook = excepthook
+sys.excepthook = Pyro5.errors.excepthook
 
 # add a bunch of topics to the bus
-bus = Pyro4.Proxy("PYRONAME:"+PYRO_MSGBUS_NAME)
+bus = Proxy("PYRONAME:"+PYRO_MSGBUS_NAME)
 for letter in "abcdefghijklmnopqrstuvwxyz":
     bus.add_topic("msg.topic.%s" % letter)
 
