@@ -2,20 +2,15 @@
 This is a subscriber meant for the 'weather' messages example.
 It uses a callback to process incoming messages.
 """
-from __future__ import print_function
 import sys
-import Pyro4
+import Pyro5.errors
+from Pyro5.api import expose, Daemon
 from messagebus.messagebus import Subscriber
-from Pyro4.util import excepthook
 
-sys.excepthook = excepthook
-if sys.version_info < (3, 0):
-    input = raw_input
-
-Pyro4.config.AUTOPROXY = True
+sys.excepthook = Pyro5.errors.excepthook
 
 
-@Pyro4.expose
+@expose
 class Subber(Subscriber):
     def consume_message(self, topic, message):
         # This callback-method is called automatically when a message arrives on the bus.
@@ -30,7 +25,7 @@ hostname = input("hostname to bind on (empty=localhost): ").strip() or "localhos
 
 # create a messagebus subscriber that uses automatic message retrieval (via a callback)
 subber = Subber()
-d = Pyro4.Daemon(host=hostname)
+d = Daemon(host=hostname)
 d.register(subber)
 
 topics = subber.bus.topics()
