@@ -2,22 +2,17 @@
 This is a subscriber meant for the 'weather' messages example.
 It uses a custom code loop to get and process messages.
 """
-from __future__ import print_function
 import sys
 import threading
 import time
-import Pyro4
+import Pyro5.errors
+from Pyro5.api import expose, Daemon
 from messagebus.messagebus import Subscriber
-from Pyro4.util import excepthook
 
-sys.excepthook = excepthook
-if sys.version_info < (3, 0):
-    input = raw_input
-
-Pyro4.config.AUTOPROXY = True
+sys.excepthook = Pyro5.errors.excepthook
 
 
-@Pyro4.expose
+@expose
 class Subber(Subscriber):
     def consume_message(self, topic, message):
         # In this case, this consume message method is called by our own code loop.
@@ -44,7 +39,7 @@ hostname = input("hostname to bind on (empty=localhost): ").strip() or "localhos
 # create a messagebus subscriber that uses manual message retrieval (via explicit call)
 # because we're doing the message loop ourselves, the Pyro daemon has to run in a separate thread
 subber = Subber(auto_consume=False)
-d = Pyro4.Daemon(host=hostname)
+d = Daemon(host=hostname)
 d.register(subber)
 daemon_thread = threading.Thread(target=d.requestLoop)
 daemon_thread.daemon = True
