@@ -1,24 +1,22 @@
 # The server that doesn't use the Name Server.
 
-from __future__ import print_function
 import os
-
-import Pyro4
+from Pyro5.api import expose, Daemon
 
 
 class QuoteGen(object):
-    @Pyro4.expose
+    @expose
     def quote(self):
         try:
             quote = os.popen('fortune').read()
             if len(quote) > 0:
                 return quote
             return "This system cannot provide you a good fortune, install 'fortune'"
-        except:
+        except Exception:
             return "This system knows no witty quotes :-("
 
 
-with Pyro4.core.Daemon() as daemon:
+with Daemon() as daemon:
     quote1 = QuoteGen()
     quote2 = QuoteGen()
 
