@@ -1,10 +1,8 @@
-from __future__ import print_function
 import os
-
-import Pyro4
+from Pyro5.api import expose, Daemon
 
 
-@Pyro4.expose
+@expose
 class Thingy(object):
     def message(self, arg):
         print("Message received:", arg)
@@ -14,7 +12,7 @@ class Thingy(object):
 if os.path.exists("example_unix.sock"):
     os.remove("example_unix.sock")
 
-with Pyro4.Daemon(unixsocket="example_unix.sock") as d:
+with Daemon(unixsocket="example_unix.sock") as d:
     uri = d.register(Thingy, "example.unixsock")
     print("Server running, uri=", uri)
     d.requestLoop()
