@@ -1,14 +1,13 @@
-from __future__ import print_function
-import Pyro4
+from Pyro5.api import behavior, expose, current_context, serve, config
 from database import DummyDatabase
 
 
-Pyro4.config.SERVERTYPE = "thread"
+config.SERVERTYPE = "thread"
 database = DummyDatabase()
 
 
-@Pyro4.behavior(instance_mode="single")
-@Pyro4.expose
+@behavior(instance_mode="single")
+@expose
 class SingletonDatabase(object):
     """
     This pyro object will exhibit problems when used from multiple proxies at the same time
@@ -20,22 +19,22 @@ class SingletonDatabase(object):
 
     def store(self, key, value):
         # get the user-token from the USER annotation
-        ctx = Pyro4.current_context
-        user = ctx.annotations["USER"].decode("utf-8")
+        user_annotation = current_context.annotations["USER"]
+        # because we will be storing it for a longer time, make an explicit textual copy of it
+        user = bytes(user_annotation).decode("utf-8")
         self.conn.store(key, value, user=user)
 
     def retrieve(self, key):
         # get the user-token from the USER annotation
-        ctx = Pyro4.current_context
-        user = ctx.annotations["USER"].decode("utf-8")
-        return self.conn.retrieve(key, user=user)
+        user_annotation = current_context.annotations["USER"]
+        return self.conn.retrieve(key, user=bytes(user_annotation).decode("utf-8"))
 
     def ping(self):
         return "hi"
 
 
-@Pyro4.behavior(instance_mode="session")
-@Pyro4.expose
+@behavior(instance_mode="session")
+@expose
 class SessionboundDatabase(object):
     """
     This pyro object will work fine when used from multiple proxies at the same time
@@ -43,8 +42,8 @@ class SessionboundDatabase(object):
     """
     def __init__(self):
         # get the user-token from the USER annotation
-        ctx = Pyro4.current_context
-        user = ctx.annotations["USER"].decode("utf-8")
+        user_annotation = current_context.annotations["USER"]
+        user = bytes(user_annotation).decode("utf-8")
         self.connection = database.connect(user)
         print("[%s] new instance and connection for user: %s" % (self.__class__.__name__, user))
 
@@ -58,7 +57,7 @@ class SessionboundDatabase(object):
         return "hi"
 
 
-Pyro4.Daemon.serveSimple({
+serve({
     SingletonDatabase: "example.usersession.singletondb",
     SessionboundDatabase: "example.usersession.sessiondb"
 })
